/* book.cpp */
/* The Book class used in an inventory-tracking program */

/* Author: Zach Tomaszewski */
/* Date: 19 Mar 2003 */


#include "inventory.h"
#include <iostream>

double Book::totalValue;  //total value of all Books.


// -------- Constructors -----------

/*
 Book constructor.
 Takes a stock number, a string name, a publisher, an author,
   a price, and a quanity in stock.
*/
Book::Book(char *stockNo, char *name, char *publisher,
           char *author, double price, int count)

          :Item(stockNo, name, price, count) {

  this->publisher = publisher;
  this->author = author;
  totalValue += price * count;
}

/*
 Item constructor.
 Takes only a stock number and a string name.
*/
Book::Book(char *stockNo, char *name, char *publisher, char *author) 
         :Item(stockNo, name){
  this->publisher = publisher;
  this->author = author;
}


// --------- Methods -------

/*
 Takes the number of this Book to add to stock.
 Updates total price for Items and Books.
*/
void Book::addStock(int n){
  //casting this to an Item to call Item's addStock.
  Item* b = (static_cast<Item*> (this));
  b->addStock(n);
  *this = *(static_cast<Book*>(b));
  totalValue += (n * getPrice());
}

/*
 Takes the number of this Book to remove from stock.
 Updates total price for Items and Books.
*/
void Book::removeStock(int n){
  //casting this to an Item to call Item's addStock.
  Item* b = (static_cast<Item*> (this));
  b->removeStock(n);
  *this = *(static_cast<Book*>(b));
  totalValue -= (n * getPrice());
}


/*
 Takes the new price for this Book.
 Updates the price as well as totalValue for all Items and all Books.
*/
void Book::setPrice(double p){
  totalValue -= (getInStock() * getPrice());
  Item* b = (static_cast<Item*> (this));
  b->setPrice(p);
  *this = *(static_cast<Book*>(b));
  totalValue += (getInStock() * getPrice());
}


/*
 Prints the Book to the screen
*/
void Book::print(){
  cout << getStockNo() << "  " << getName();
  cout << "  \tPrice: $" << getPrice();
  cout << "\t" << getInStock() << " in stock\n";
  cout << "  Author: " << getAuthor();
  cout << "  \t\tPublisher: " << getPublisher() << endl;
}
