/* software.cpp */
/* The Software class used in an inventory-tracking program */

/* Author: Zach Tomaszewski */
/* Date: 19 Mar 2003 */


#include "inventory.h"
#include <iostream>

double Software::totalValue;  //total value of all Software.


// -------- Constructors -----------

/*
 Software constructor.
 Takes a stock number, a string name, a publisher, a version,
   a price, and a quanity in stock.
*/
Software::Software(char *stockNo, char *name, char *publisher,
           char *version, double price, int count)

          :Item(stockNo, name, price, count) {

  this->publisher = publisher;
  this->version = version;
  totalValue += price * count;
}

/*
 Software constructor.
 Takes only a stock number and a string name.
*/
Software::Software(char *stockNo, char *name, 
                   char *publisher, char *version) 
         :Item(stockNo, name){
  this->publisher = publisher;
  this->version = version;
}


// --------- Methods -------

/*
 Takes the number of this Software to add to stock.
 Updates total price for Items and Software.
*/
void Software::addStock(int n){
  //casting this to an Item to call Item's addStock.
  Item* b = (static_cast<Item*> (this));
  b->addStock(n);
  *this = *(static_cast<Software*>(b));
  totalValue += (n * getPrice());
}

/*
 Takes the number of this Software to remove from stock.
 Updates total price for Items and Softwares.
*/
void Software::removeStock(int n){
  //casting this to an Item to call Item's addStock.
  Item* b = (static_cast<Item*> (this));
  b->removeStock(n);
  *this = *(static_cast<Software*>(b));
  totalValue -= (n * getPrice());
}


/*
 Takes the new price for this Software.
 Updates the price as well as totalValue for all Items and all Software.
*/
void Software::setPrice(double p){
  totalValue -= (getInStock() * getPrice());
  Item* b = (static_cast<Item*> (this));
  b->setPrice(p);
  *this = *(static_cast<Software*>(b));
  totalValue += (getInStock() * getPrice());
}


/*
 Prints the Software to the screen
*/
void Software::print(){
  cout << getStockNo() << "  " << getName();
  cout << "  \tPrice: $" << getPrice();
  cout << "\t" << getInStock() << " in stock" << endl;
  cout << "  Publisher: " << getPublisher();
  cout << "  \tVersion: " << getVersion(); 
  cout << endl;
}

